"""Main module for PyBryt CLI"""

from .cli import cli


if __name__ == "__main__":
    cli()
